mixedFontBinom: Tip Label Preparation

Description Usage Arguments Value Author(s) See Also Examples

Description

This function makes use of expressions to prepare tip labels of a tree for plotting and thereby cares for setting strings in italianor plein and produce the times symbol in hybrid taxa.

Usage

1
mixedFontBinom(x, always.upright = c("sp.", "ssp.", "aff.", "cf."))

Arguments

x

a vector of mode "character" representing the tip labels of a tree

always.upright

a vector of mode "character" giving the strings that will not be set in italics.

Value

a vector of expressions

Author(s)

Christoph Heibl, using code by Emmanuel Paradis

See Also

append2tips for plotting more text or symbols at the tips of a tree.

Examples

 1
 2
 3
 4
 5
 6
 7
 8
 9
10
11
12
13
14
15
## an examples tree
tr <- read.tree(text = "(((a,(b,c)),d), e);")
tr$tip.label <- c("Gorilla_gorilla", 
                  "Pan_sp.", 
                  "Homo_sapiens_ssp._sapiens", 
                  "Pongo_pygmaeus", 
                  "Mentha_x_piperita")
                  
## prepare tip labels ...                 
tr$tip.label <- mixedFontBinom(tr$tip.label, 
                              always.upright = c("sp.", "ssp."))
                                  
## ... and plot
plot(tr)
plot(tr, tip.color = c(rep("black", 4), "green"))

heibl/viper documentation built on May 21, 2019, 10:47 a.m.