The package provides functions for plotting phylogenetic data.
| Package: | viper |
| Type: | Package |
| Version: | 1.0-0 |
| Date: | 2014-01-15 |
| License: | GPL (>= 2) |
viper provides functions that are designed to work with phylogenetic trees represented as objects of class phylo in R.
Christoph Heibl Maintainer: Christoph Heibl <christoph.heibl@gmx.net>
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.