Description Usage Arguments Value Author(s) See Also Examples
This function makes use of expressions to prepare tip labels of a tree for plotting and thereby cares for setting strings in italianor plein and produce the times symbol in hybrid taxa.
1 | mixedFontBinom(x, always.upright = c("sp.", "ssp.", "aff.", "cf."))
|
x |
a vector of mode |
always.upright |
a vector of mode |
a vector of expressions
Christoph Heibl, using code by Emmanuel Paradis
append2tips for plotting more text or symbols at the tips of a tree.
1 2 3 4 5 6 7 8 9 10 11 12 13 14 15 | ## an examples tree
tr <- read.tree(text = "(((a,(b,c)),d), e);")
tr$tip.label <- c("Gorilla_gorilla",
"Pan_sp.",
"Homo_sapiens_ssp._sapiens",
"Pongo_pygmaeus",
"Mentha_x_piperita")
## prepare tip labels ...
tr$tip.label <- mixedFontBinom(tr$tip.label,
always.upright = c("sp.", "ssp."))
## ... and plot
plot(tr)
plot(tr, tip.color = c(rep("black", 4), "green"))
|
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.